@@ -477,9 +477,16 @@ def test_channel_config_set(com_config, dev_config):
         assert ch2_config.input_range is ir
 
     # probe offset
-    probe_offset_value = 1
-    ch2_config.probe_offset = probe_offset_value
-    assert ch2_config.probe_offset == probe_offset_value
+    with pytest.raises(NotImplementedError):
+        ch2_config.probe_offset = 1
+    with pytest.raises(NotImplementedError):
+        assert ch2_config.probe_offset == 1
+
+    # probe gain
+    with pytest.raises(NotImplementedError):
+        ch2_config.probe_gain = 1
+    with pytest.raises(NotImplementedError):
+        assert ch2_config.probe_gain == 1
 
     # safeground enabled
     ch2_config.channel.enable_safeground_option()
@@ -563,13 +570,6 @@ def test_channel_config_set_invalid(com_config, dev_config):
     with pytest.raises(ValueError):
         ch_config.input_range = 234567
 
-    # probe_offset
-    for v in (-1e7, 1e7):
-        with pytest.raises(ValueError):
-            ch_config.probe_offset = v
-    with pytest.raises(TypeError):
-        ch_config.probe_offset = "1"
-
     # safeground_enabled
     for v in ("True", 1):
         with pytest.raises(TypeError):
@@ -817,8 +817,15 @@ def test_generate_signal(com_config, dev_config):
 
     dev_ws5.start()
 
+    assert not dev_ws5.generator_is_running
+
     dev_ws5.generator_start()
+    dev_ws5.generator_start()
+    assert dev_ws5.generator_is_running
     dev_ws5.generator_stop()
+    dev_ws5.generator_stop()
+
+    assert not dev_ws5.generator_is_running
 
     dev_ws5.stop()
 
